-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_07:StartActivity()
	-- All comments are removed, I left only comments which describe the multiple faction thing
	print("START! -- MissionTutorial_07:StartActivity()!");

	-- Load campaign framework library files. They contain all global functions and variables
	-- started with CF_
	-- This is a simple library from Tartarus and BlockWars which use the simple faction
	-- format. You can take libraries from Unmapped lands and get more function but you'll
	-- have to use more complex Unmapped Lands faction files

	-- Config library responsible for working with config files
	dofile ("ExtendedActivities.rte/Libraries/CF_ConfigLibrary.lua");
	-- Mission library does mission specific stuff, spawning etc.
	dofile ("ExtendedActivities.rte/Libraries/CF_MissionLibrary.lua");

	-- Initialize campaign framework. Load faction lists, init fariables etc.
	CF_InitFactions("ExtendedActivities.rte");
	
	self.DummyLZ = SceneMan.Scene:GetArea("DummyLZ");

	self.Zone = SceneMan.Scene:GetArea("MissionTut_07_Area");
	
	self.braindead = {};
	self.AssignedBrains = {};
	self.MOIDLimit = 200;
    
	self.PlayerGold = 0;

   	self.CPUTeam = Activity.TEAM_2;
	self.PlayerTeam = Activity.TEAM_1;
	self.RogueTeam = -1;

	self.DummySpawnTimer = Timer();
	self.CoalitionSpawnTimer = Timer();
	
	self.DummySpawnInterval = 16000;
	self.CoalitionSpawnInterval = 8000;
	
	for player = 0, self.PlayerCount - 1 do
        if not self:GetPlayerBrain(player) then
			self.braindead[player] = false;
			local brain = CreateAHuman("Brain Robot" , "base.rte");
			brain.Pos = Vector(150 + player * 30 , 550);
			brain:AddInventoryItem(CreateHDFirearm("Auto Pistol" , "Coalition.rte"));
			brain.AIMode = Actor.AIMODE_SENTRY;
			self.AssignedBrains[player] = brain;
            MovableMan:AddActor(brain);
            self:SetPlayerBrain(brain, player);
            SceneMan:SetScroll(self:GetPlayerBrain(player).Pos, player);
            self:SetObservationTarget(self:GetPlayerBrain(player).Pos, player);
			self:SwitchToActor(brain, player, self.PlayerTeam);
        end
    end

    for actor in MovableMan.AddedActors do
		actor.AIMode = Actor.AIMODE_SENTRY;
    end
	
    self:SetTeamFunds(self.PlayerGold , self.PlayerTeam);
	
	self.DummySpawnTimer:Reset();
	self.CoalitionSpawnTimer:Reset();
end
-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_07:PauseActivity(pause)
    print("PAUSE! -- MissionTutorial_07:PauseActivity()!");
end
-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_07:EndActivity()
    print("END! -- MissionTutorial_07:EndActivity()!");
end
-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------
function MissionTutorial_07:UpdateActivity()
   	self:ClearObjectivePoints();

	self:PhaseNoFight();
	
	self:DoBrainSelection();
	
	self:YSortObjectivePoints();
end
-----------------------------------------------------------------------------------------
-- Brain selection and gameover conditions check
-----------------------------------------------------------------------------------------
function MissionTutorial_07:DoBrainSelection()
	if not (self.ActivityState == Activity.OVER) then
		for player = 0, self.PlayerCount - 1 do
			local team = self:GetTeamOfPlayer(player);
	
			local brain = self:GetPlayerBrain(player);
			if not brain or not MovableMan:IsActor(brain) then
				self:SetPlayerBrain(nil, player);
				local newBrain = MovableMan:GetUnassignedBrain(team);
				if newBrain and self.braindead[player] == false then
					self:SetPlayerBrain(newBrain, player);
					self:SwitchToActor(newBrain, player, team);
				else
					FrameMan:SetScreenText("Commander died!", player, 100, -1, false);
					self.braindead[player] = true;
					
					self.WinnerTeam = self:OtherTeam(team);
					ActivityMan:EndActivity();
				end
			else
				self:SetObservationTarget(brain.Pos, player)
			end -- 
		end --for
	end --if
end
-----------------------------------------------------------------------------------------
-- Spawn dummy dropship
-----------------------------------------------------------------------------------------
function MissionTutorial_07:SpawnDummyDropship()
		local ship = CreateACDropShip("Drop Ship", "Dummy.rte");
		local actor = nil;
		local weapon = nil;
		
		for i = 0 , 1 do
				if math.random() > 0.05 then
					-- Get random unit with random weapons. 
					-- Team = self.CPUTeam. 
					-- Position = nil, means that actor won't be placed but returned as function result.
					-- Faction - CF_Factions[math.random(#CF_Factions)], choose random faction from list
					-- AIMODE - Actor.AIMODE_BRAINHUNT
					actor = CF_SpawnRandomInfantry(self.CPUTeam , nil , CF_Factions[math.random(#CF_Factions)] , Actor.AIMODE_BRAINHUNT)
					-- Give new actor some special equipment
					actor:AddInventoryItem(CreateHDFirearm("Medium Digger"));
				else
					-- Spawn armor unit of selected faction. Arguments are the same as for CF_SpawnRandomInfantry
					actor[x] = CF_SpawnArmor(self.CPUTeam , nil , CF_Factions[math.random(#CF_Factions)] , Actor.AIMODE_BRAINHUNT)
					break;
				end

			ship:AddInventoryItem(actor);
		end -- for

		ship.Pos = Vector(self.DummyLZ:GetRandomPoint().X, 0);
		ship.Team = self.CPUTeam;
		ship:SetControllerMode(Controller.CIM_AI, -1);

		MovableMan:AddActor(ship);
end
-----------------------------------------------------------------------------------------
-- Phase "No fight"
-----------------------------------------------------------------------------------------
function MissionTutorial_07:SpawnClone()

	-- Spawn friendly unit
	actor = CF_SpawnRandomInfantry(self.PlayerTeam , nil , CF_Factions[math.random(#CF_Factions)] , Actor.AIMODE_BRAINHUNT)

	-- Reset it's AImode to more complex
	actor.AIMode = Actor.AIMODE_GOTO;
	actor:ClearAIWaypoints();
	actor:AddAISceneWaypoint(Vector(1800 , 550));
	actor.Pos = Vector( 10 , 550);
	MovableMan:AddActor(actor);
end
-----------------------------------------------------------------------------------------
-- Phase "No fight"
-----------------------------------------------------------------------------------------
function MissionTutorial_07:PhaseNoFight()
	if self.DummySpawnTimer:IsPastSimMS(self.DummySpawnInterval) and MovableMan:GetMOIDCount() <= self.MOIDLimit then
		self:SpawnDummyDropship();
		self.DummySpawnTimer:Reset();
	end

	if self.CoalitionSpawnTimer:IsPastSimMS(self.CoalitionSpawnInterval) and MovableMan:GetMOIDCount() <= self.MOIDLimit then
		self:SpawnClone();
		self.CoalitionSpawnTimer:Reset();
	end
end
-----------------------------------------------------------------------------------------
-- That's all folks!
-----------------------------------------------------------------------------------------



































